@@ -2,7 +2,7 @@ VER=$1
 
 . ./clean.sh
 
-svn co https://testman4trac.svn.sourceforge.net/svnroot/testman4trac testman4trac.$VER.SVN
+svn checkout --username=seccanj svn+ssh://seccanj@svn.code.sf.net/p/testman4trac/code/ testman4trac.$VER.SVN
 cd testman4trac.$VER.SVN
 cp -R ../testman4trac.$VER/* .
 svn status
