@@ -425,7 +425,7 @@ class WikiTestManagerInterface(Component):
     
         tc_id = tc_name.partition('_TC')[2]
         test_case = TestCase(self.env, tc_id, tc_name)
-        summary = str(test_case.title)
+        summary = test_case.title
 
         tcat = TestCatalog(self.env, cat_id)
         
@@ -957,7 +957,7 @@ class WikiTestManagerInterface(Component):
             <div id="dialog_organize" style="padding:20px; display:none;" title=\"""" + _("Organize Test Catalogs") + """\">
                 <form id="organize_form_id" name="organize_form_id" class="addnew" method="post" action="%s/testorganize">
                 """ + _("Drag and drop the test cases to reorder them, or to move them to different catalogs.") + """
-                <br />
+                <br /><br />
                 """ + self._build_catalog_organize(cat_name) + """ 
                 <fieldset>
                     <div class="buttons">
@@ -986,7 +986,7 @@ class WikiTestManagerInterface(Component):
     
     def _write_common_code(self, req, add_statuses_and_colors=False, add_menu=False):
         add_stylesheet(req, 'common/css/report.css')
-        add_stylesheet(req, 'testmanager/css/blitzer/jquery-ui-1.10.0.custom.css')
+        add_stylesheet(req, 'testmanager/css/blitzer/jquery-ui-1.10.3.custom.min.css')
         add_stylesheet(req, 'testmanager/css/jquery.uix.tree.css')
         add_stylesheet(req, 'testmanager/css/testmanager.css')
         add_stylesheet(req, 'testmanager/css/nestedSortable.css')
@@ -1004,7 +1004,7 @@ class WikiTestManagerInterface(Component):
             HTML(self._get_error_dialog_markup(req)),
             tag.script(before_jquery, type='text/javascript'),
             tag.script(src='../chrome/testmanager/js/jquery-1.9.1.min.js', type='text/javascript'),
-            tag.script(src='../chrome/testmanager/js/jquery-ui-1.10.0.custom.min.js', type='text/javascript'),
+            tag.script(src='../chrome/testmanager/js/jquery-ui-1.10.3.custom.min.js', type='text/javascript'),
             tag.script(after_jquery, type='text/javascript'),
             tag.script(src='../chrome/testmanager/js/cookies.js', type='text/javascript'),
             tag.script(src='../chrome/testmanager/js/testmanager.js', type='text/javascript'),
@@ -1649,7 +1649,7 @@ class WikiTestManagerInterface(Component):
                 text += '<li name="testcatalog" catid="%s" level="%s" class="mjs-nestedSortable-branch">' % (comp['tcat_id'], level)
 
                 # Anchor to drag the row
-                text += '<div><span class="disclose"><span></span></span>'
+                text += '<div><span class="testCatalogIcon"></span>'
                 
                 # Title
                 #text += '<span name="title" style="padding-left: '+str(level*30)+'px;">'+comp['title']+'</span>'
@@ -1683,7 +1683,7 @@ class WikiTestManagerInterface(Component):
             text += '<li name="testcase" catid="%s" tcid="%s" level="%s" execorder="%s" class="ui-nestedSortable-no-nesting mjs-nestedSortable-leaf">' % (tcatId, tick['tc_id'], level, tick['exec_order'])
 
             # Anchor to drag the row
-            text += '<div><span class="disclose"><span></span></span>'
+            text += '<div><span class="testCaseIcon"></span>'
             
             # Title
             text += '<span name="title">'+tick['title']+'</span>'
